@@ -28,7 +28,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 
 #include "user_share-private.h"
 
@@ -36,7 +35,7 @@
 #define USER "guest"
 
 static GtkBuilder* builder;
-
+static GSettings*  settings;
 
 static void
 write_out_password (const char *password)
@@ -84,7 +83,6 @@ flush_password (void)
 static void
 update_ui (void)
 {
-    GConfClient *client;
     gboolean enabled, bluetooth_enabled, bluetooth_write_enabled, require_pairing_enabled;
     gboolean bluetooth_obexpush_enabled, bluetooth_obexpush_notify;
     char *str;
@@ -100,32 +98,24 @@ update_ui (void)
     GtkWidget *accept_obexpush_combo;
     GtkWidget *notify_received_obexpush_check;
 
-    client = gconf_client_get_default ();
+    enabled = g_settings_get_boolean (settings,
+				      FILE_SHARING_ENABLED);
+    bluetooth_enabled = g_settings_get_boolean (settings,
+						FILE_SHARING_BLUETOOTH_ENABLED);
+    bluetooth_write_enabled = g_settings_get_boolean (settings,
+						      FILE_SHARING_BLUETOOTH_ALLOW_WRITE);
+    require_pairing_enabled = g_settings_get_boolean (settings,
+						      FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING);
+    bluetooth_obexpush_enabled = g_settings_get_boolean (settings,
+							 FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED);
+    bluetooth_obexpush_notify = g_settings_get_boolean (settings,
+							FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY);
 
-    enabled = gconf_client_get_bool (client,
-				     FILE_SHARING_ENABLED,
-				     NULL);
-    bluetooth_enabled = gconf_client_get_bool (client,
-    					       FILE_SHARING_BLUETOOTH_ENABLED,
-    					       NULL);
-    bluetooth_write_enabled = gconf_client_get_bool (client,
-						     FILE_SHARING_BLUETOOTH_ALLOW_WRITE,
-						     NULL);
-    require_pairing_enabled = gconf_client_get_bool (client,
-    						     FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING,
-    						     NULL);
-    bluetooth_obexpush_enabled = gconf_client_get_bool (client,
-    							FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED,
-    							NULL);
-    bluetooth_obexpush_notify = gconf_client_get_bool (client,
-    						       FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY,
-    						       NULL);
-
-    str = gconf_client_get_string (client, FILE_SHARING_REQUIRE_PASSWORD, NULL);
+    str = g_settings_get_string (settings, FILE_SHARING_REQUIRE_PASSWORD);
     password_setting = password_setting_from_string (str);
     g_free (str);
 
-    str = gconf_client_get_string (client, FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES, NULL);
+    str = g_settings_get_string (settings, FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES);
     accept_setting = accept_setting_from_string (str);
     g_free (str);
 
@@ -167,137 +157,37 @@ update_ui (void)
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (accept_obexpush_combo),
     			      accept_setting);
-
-    g_object_unref (client);
-}
-
-static void
-file_sharing_enabled_changed (GConfClient* client,
-			      guint cnxn_id,
-			      GConfEntry *entry,
-			      gpointer data)
-{
-    update_ui ();
-}
-
-static void
-password_required_changed (GConfClient* client,
-			   guint cnxn_id,
-			   GConfEntry *entry,
-			   gpointer data)
-{
-    update_ui ();
-}
-
-static void
-file_sharing_bluetooth_enabled_changed (GConfClient* client,
-					guint cnxn_id,
-					GConfEntry *entry,
-					gpointer data)
-{
-	update_ui ();
-}
-
-static void
-file_sharing_bluetooth_allow_write_changed (GConfClient* client,
-					    guint cnxn_id,
-					    GConfEntry *entry,
-					    gpointer data)
-{
-	update_ui ();
-}
-
-static void
-file_sharing_bluetooth_require_pairing_changed (GConfClient* client,
-						guint cnxn_id,
-						GConfEntry *entry,
-						gpointer data)
-{
-	update_ui ();
-}
-
-static void
-file_sharing_bluetooth_obexpush_enabled_changed (GConfClient* client,
-						 guint cnxn_id,
-						 GConfEntry *entry,
-						 gpointer data)
-{
-	update_ui ();
-}
-
-static void
-file_sharing_bluetooth_obexpush_accept_files_changed (GConfClient* client,
-						      guint cnxn_id,
-						      GConfEntry *entry,
-						      gpointer data)
-{
-	update_ui ();
-}
-
-static void
-file_sharing_bluetooth_obexpush_notify_changed (GConfClient* client,
-						guint cnxn_id,
-						GConfEntry *entry,
-						gpointer data)
-{
-	update_ui ();
 }
 
 static void
 password_combo_changed (GtkComboBox *combo_box)
 {
-    GConfClient *client;
     guint setting;
 
     setting = gtk_combo_box_get_active (combo_box);
 
-    client = gconf_client_get_default ();
-
-    gconf_client_set_string (client,
+    g_settings_set_string (settings,
 			     FILE_SHARING_REQUIRE_PASSWORD,
-			     password_string_from_setting (setting),
-			     NULL);
-    g_object_unref (client);
+			     password_string_from_setting (setting));
 }
 
 static void
 launch_share (void)
 {
-	char *argv[2];
-	int i;
-
-	i = 0;
-	argv[i++] = USER_SHARE_PROGRAM;
-	argv[i++] = NULL;
-
-	if (!g_spawn_async (NULL,
-			    argv,
-			    NULL,
-			    0, /* G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL */
-			    NULL,
-			    NULL,
-			    NULL,
-			    NULL)) {
+	if (!g_spawn_command_line_async (USER_SHARE_PROGRAM, NULL))
 		g_warning ("Unable to start gnome-user-share program");
-	}
 }
 
 static void
 enable_bluetooth_check_toggled (GtkWidget *check)
 {
-	GConfClient *client;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = gconf_client_get_default ();
-
-	gconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_ENABLED,
-			       enabled,
-			       NULL);
-
-	g_object_unref (client);
+			       enabled);
 
 	if (enabled != FALSE)
 		launch_share ();
@@ -306,19 +196,13 @@ enable_bluetooth_check_toggled (GtkWidget *check)
 static void
 enable_check_toggled (GtkWidget *check)
 {
-	GConfClient *client;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = gconf_client_get_default ();
-
-	gconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_ENABLED,
-			       enabled,
-			       NULL);
-
-	g_object_unref (client);
+			       enabled);
 
 	if (enabled != FALSE)
 		launch_share ();
@@ -335,55 +219,37 @@ password_entry_changed (GtkEditable *editable)
 static void
 bluetooth_allow_write_check_toggled (GtkWidget *check)
 {
-	GConfClient *client;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = gconf_client_get_default ();
-
-	gconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_ALLOW_WRITE,
-			       enabled,
-			       NULL);
-
-	g_object_unref (client);
+			       enabled);
 }
 
 static void
 bluetooth_require_pairing_check_toggled (GtkWidget *check)
 {
-	GConfClient *client;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = gconf_client_get_default ();
-
-	gconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING,
-			       enabled,
-			       NULL);
-
-	g_object_unref (client);
+			       enabled);
 }
 
 static void
 enable_obexpush_check_toggled (GtkWidget *check)
 {
-	GConfClient *client;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = gconf_client_get_default ();
-
-	gconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED,
-			       enabled,
-			       NULL);
-
-	g_object_unref (client);
+			       enabled);
 
 	if (enabled != FALSE)
 		launch_share ();
@@ -392,36 +258,25 @@ enable_obexpush_check_toggled (GtkWidget *check)
 static void
 accept_obexpush_combo_changed (GtkComboBox *combo_box)
 {
-    GConfClient *client;
     guint setting;
 
     setting = gtk_combo_box_get_active (combo_box);
 
-    client = gconf_client_get_default ();
-
-    gconf_client_set_string (client,
+    g_settings_set_string (settings,
 			     FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES,
-			     accept_string_from_setting (setting),
-			     NULL);
-    g_object_unref (client);
+			     accept_string_from_setting (setting));
 }
 
 static void
 notify_received_obexpush_check_toggled (GtkWidget *check)
 {
-	GConfClient *client;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = gconf_client_get_default ();
-
-	gconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY,
-			       enabled,
-			       NULL);
-
-	g_object_unref (client);
+			       enabled);
 }
 
 static GtkWidget *
@@ -457,7 +312,7 @@ help_button_clicked (GtkButton *button, GtkWidget *window)
 {
 	GError *error = NULL;
 
-	if (gtk_show_uri (gtk_widget_get_screen (window), "ghelp:gnome-user-share", gtk_get_current_event_time (), &error) == FALSE) {
+	if (gtk_show_uri (gtk_widget_get_screen (window), "help:gnome-user-share", gtk_get_current_event_time (), &error) == FALSE) {
 		GtkWidget *dialog;
 
 		dialog = error_dialog (_("Could not display the help contents."), error->message, GTK_WINDOW (window));
@@ -473,7 +328,6 @@ static GtkWidget *
 create_window (void)
 {
     GError *error = NULL;
-    GConfClient *client;
     GtkWidget *check;
     GtkWidget *password_combo;
     GtkWidget *password_entry;
@@ -504,12 +358,6 @@ create_window (void)
 
     window = GTK_WIDGET (gtk_builder_get_object (builder, "user_share_dialog"));
 
-    client = gconf_client_get_default ();
-    gconf_client_add_dir (client,
-			  FILE_SHARING_DIR,
-			  GCONF_CLIENT_PRELOAD_RECURSIVE,
-			  NULL);
-
     check = GTK_WIDGET (gtk_builder_get_object (builder, "enable_check"));
     password_combo = GTK_WIDGET (gtk_builder_get_object (builder, "password_combo"));
     password_entry = GTK_WIDGET (gtk_builder_get_object (builder, "password_entry"));
@@ -598,56 +446,7 @@ create_window (void)
 		      "clicked", G_CALLBACK (help_button_clicked),
 		      gtk_builder_get_object (builder, "user_share_dialog"));
 
-    gconf_client_notify_add (client,
-			     FILE_SHARING_ENABLED,
-			     file_sharing_enabled_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    gconf_client_notify_add (client,
-			     FILE_SHARING_REQUIRE_PASSWORD,
-			     password_required_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    gconf_client_notify_add (client,
-			     FILE_SHARING_BLUETOOTH_ENABLED,
-			     file_sharing_bluetooth_enabled_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    gconf_client_notify_add (client,
-			     FILE_SHARING_BLUETOOTH_ALLOW_WRITE,
-			     file_sharing_bluetooth_allow_write_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    gconf_client_notify_add (client,
-			     FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING,
-			     file_sharing_bluetooth_require_pairing_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    gconf_client_notify_add (client,
-    			     FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED,
-    			     file_sharing_bluetooth_obexpush_enabled_changed,
-    			     NULL,
-    			     NULL,
-    			     NULL);
-    gconf_client_notify_add (client,
-    			     FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES,
-    			     file_sharing_bluetooth_obexpush_accept_files_changed,
-    			     NULL,
-    			     NULL,
-    			     NULL);
-    gconf_client_notify_add (client,
-    			     FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY,
-			     file_sharing_bluetooth_obexpush_notify_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-
-    g_object_unref (client);
+    g_signal_connect_swapped (settings, "changed", G_CALLBACK(update_ui), NULL);
 
     return window;
 }
@@ -679,8 +478,12 @@ main (int argc, char *argv[])
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
 
+    g_set_prgname ("gnome-user-share-properties");
+
     app = gtk_application_new ("org.gnome.user-share.properties",
                                G_APPLICATION_FLAGS_NONE);
+    settings = g_settings_new (GNOME_USER_SHARE_SCHEMAS);
+
     g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
 
     status = g_application_run (G_APPLICATION (app), argc, argv);
